@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Mapping, Sequence
+from typing import Any, Dict, List, Mapping, Sequence, Union
 
 from .literals import (
     AccessTypeType,
@@ -41,6 +41,7 @@ __all__ = (
     "AdBreakTypeDef",
     "AdMarkerPassthroughTypeDef",
     "AlertTypeDef",
+    "AvailMatchingCriteriaTypeDef",
     "AvailSuppressionTypeDef",
     "BumperTypeDef",
     "CdnConfigurationTypeDef",
@@ -49,6 +50,8 @@ __all__ = (
     "ConfigureLogsForPlaybackConfigurationResponseTypeDef",
     "CreateChannelRequestRequestTypeDef",
     "CreateChannelResponseTypeDef",
+    "CreatePrefetchScheduleRequestRequestTypeDef",
+    "CreatePrefetchScheduleResponseTypeDef",
     "CreateProgramRequestRequestTypeDef",
     "CreateProgramResponseTypeDef",
     "CreateSourceLocationRequestRequestTypeDef",
@@ -62,6 +65,7 @@ __all__ = (
     "DeleteChannelPolicyRequestRequestTypeDef",
     "DeleteChannelRequestRequestTypeDef",
     "DeletePlaybackConfigurationRequestRequestTypeDef",
+    "DeletePrefetchScheduleRequestRequestTypeDef",
     "DeleteProgramRequestRequestTypeDef",
     "DeleteSourceLocationRequestRequestTypeDef",
     "DeleteVodSourceRequestRequestTypeDef",
@@ -79,6 +83,8 @@ __all__ = (
     "GetChannelScheduleResponseTypeDef",
     "GetPlaybackConfigurationRequestRequestTypeDef",
     "GetPlaybackConfigurationResponseTypeDef",
+    "GetPrefetchScheduleRequestRequestTypeDef",
+    "GetPrefetchScheduleResponseTypeDef",
     "HlsConfigurationTypeDef",
     "HlsPlaylistSettingsTypeDef",
     "HttpConfigurationTypeDef",
@@ -89,6 +95,8 @@ __all__ = (
     "ListChannelsResponseTypeDef",
     "ListPlaybackConfigurationsRequestRequestTypeDef",
     "ListPlaybackConfigurationsResponseTypeDef",
+    "ListPrefetchSchedulesRequestRequestTypeDef",
+    "ListPrefetchSchedulesResponseTypeDef",
     "ListSourceLocationsRequestRequestTypeDef",
     "ListSourceLocationsResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
@@ -100,6 +108,9 @@ __all__ = (
     "ManifestProcessingRulesTypeDef",
     "PaginatorConfigTypeDef",
     "PlaybackConfigurationTypeDef",
+    "PrefetchConsumptionTypeDef",
+    "PrefetchRetrievalTypeDef",
+    "PrefetchScheduleTypeDef",
     "PutChannelPolicyRequestRequestTypeDef",
     "PutPlaybackConfigurationRequestRequestTypeDef",
     "PutPlaybackConfigurationResponseTypeDef",
@@ -166,6 +177,14 @@ AlertTypeDef = TypedDict(
     },
 )
 
+AvailMatchingCriteriaTypeDef = TypedDict(
+    "AvailMatchingCriteriaTypeDef",
+    {
+        "DynamicVariable": str,
+        "Operator": Literal["EQUALS"],
+    },
+)
+
 AvailSuppressionTypeDef = TypedDict(
     "AvailSuppressionTypeDef",
     {
@@ -276,6 +295,44 @@ CreateChannelResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredCreatePrefetchScheduleRequestRequestTypeDef = TypedDict(
+    "_RequiredCreatePrefetchScheduleRequestRequestTypeDef",
+    {
+        "Consumption": "PrefetchConsumptionTypeDef",
+        "Name": str,
+        "PlaybackConfigurationName": str,
+        "Retrieval": "PrefetchRetrievalTypeDef",
+    },
+)
+_OptionalCreatePrefetchScheduleRequestRequestTypeDef = TypedDict(
+    "_OptionalCreatePrefetchScheduleRequestRequestTypeDef",
+    {
+        "StreamId": str,
+    },
+    total=False,
+)
+
+
+class CreatePrefetchScheduleRequestRequestTypeDef(
+    _RequiredCreatePrefetchScheduleRequestRequestTypeDef,
+    _OptionalCreatePrefetchScheduleRequestRequestTypeDef,
+):
+    pass
+
+
+CreatePrefetchScheduleResponseTypeDef = TypedDict(
+    "CreatePrefetchScheduleResponseTypeDef",
+    {
+        "Arn": str,
+        "Consumption": "PrefetchConsumptionTypeDef",
+        "Name": str,
+        "PlaybackConfigurationName": str,
+        "Retrieval": "PrefetchRetrievalTypeDef",
+        "StreamId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredCreateProgramRequestRequestTypeDef = TypedDict(
     "_RequiredCreateProgramRequestRequestTypeDef",
     {
@@ -452,6 +509,14 @@ DeletePlaybackConfigurationRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeletePrefetchScheduleRequestRequestTypeDef = TypedDict(
+    "DeletePrefetchScheduleRequestRequestTypeDef",
+    {
+        "Name": str,
+        "PlaybackConfigurationName": str,
+    },
+)
+
 DeleteProgramRequestRequestTypeDef = TypedDict(
     "DeleteProgramRequestRequestTypeDef",
     {
@@ -646,6 +711,27 @@ GetPlaybackConfigurationResponseTypeDef = TypedDict(
     },
 )
 
+GetPrefetchScheduleRequestRequestTypeDef = TypedDict(
+    "GetPrefetchScheduleRequestRequestTypeDef",
+    {
+        "Name": str,
+        "PlaybackConfigurationName": str,
+    },
+)
+
+GetPrefetchScheduleResponseTypeDef = TypedDict(
+    "GetPrefetchScheduleResponseTypeDef",
+    {
+        "Arn": str,
+        "Consumption": "PrefetchConsumptionTypeDef",
+        "Name": str,
+        "PlaybackConfigurationName": str,
+        "Retrieval": "PrefetchRetrievalTypeDef",
+        "StreamId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 HlsConfigurationTypeDef = TypedDict(
     "HlsConfigurationTypeDef",
     {
@@ -745,6 +831,39 @@ ListPlaybackConfigurationsResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListPrefetchSchedulesRequestRequestTypeDef = TypedDict(
+    "_RequiredListPrefetchSchedulesRequestRequestTypeDef",
+    {
+        "PlaybackConfigurationName": str,
+    },
+)
+_OptionalListPrefetchSchedulesRequestRequestTypeDef = TypedDict(
+    "_OptionalListPrefetchSchedulesRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+        "StreamId": str,
+    },
+    total=False,
+)
+
+
+class ListPrefetchSchedulesRequestRequestTypeDef(
+    _RequiredListPrefetchSchedulesRequestRequestTypeDef,
+    _OptionalListPrefetchSchedulesRequestRequestTypeDef,
+):
+    pass
+
+
+ListPrefetchSchedulesResponseTypeDef = TypedDict(
+    "ListPrefetchSchedulesResponseTypeDef",
+    {
+        "Items": List["PrefetchScheduleTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListSourceLocationsRequestRequestTypeDef = TypedDict(
     "ListSourceLocationsRequestRequestTypeDef",
     {
@@ -869,6 +988,73 @@ PlaybackConfigurationTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredPrefetchConsumptionTypeDef = TypedDict(
+    "_RequiredPrefetchConsumptionTypeDef",
+    {
+        "EndTime": Union[datetime, str],
+    },
+)
+_OptionalPrefetchConsumptionTypeDef = TypedDict(
+    "_OptionalPrefetchConsumptionTypeDef",
+    {
+        "AvailMatchingCriteria": Sequence["AvailMatchingCriteriaTypeDef"],
+        "StartTime": Union[datetime, str],
+    },
+    total=False,
+)
+
+
+class PrefetchConsumptionTypeDef(
+    _RequiredPrefetchConsumptionTypeDef, _OptionalPrefetchConsumptionTypeDef
+):
+    pass
+
+
+_RequiredPrefetchRetrievalTypeDef = TypedDict(
+    "_RequiredPrefetchRetrievalTypeDef",
+    {
+        "EndTime": Union[datetime, str],
+    },
+)
+_OptionalPrefetchRetrievalTypeDef = TypedDict(
+    "_OptionalPrefetchRetrievalTypeDef",
+    {
+        "DynamicVariables": Mapping[str, str],
+        "StartTime": Union[datetime, str],
+    },
+    total=False,
+)
+
+
+class PrefetchRetrievalTypeDef(
+    _RequiredPrefetchRetrievalTypeDef, _OptionalPrefetchRetrievalTypeDef
+):
+    pass
+
+
+_RequiredPrefetchScheduleTypeDef = TypedDict(
+    "_RequiredPrefetchScheduleTypeDef",
+    {
+        "Arn": str,
+        "Consumption": "PrefetchConsumptionTypeDef",
+        "Name": str,
+        "PlaybackConfigurationName": str,
+        "Retrieval": "PrefetchRetrievalTypeDef",
+    },
+)
+_OptionalPrefetchScheduleTypeDef = TypedDict(
+    "_OptionalPrefetchScheduleTypeDef",
+    {
+        "StreamId": str,
+    },
+    total=False,
+)
+
+
+class PrefetchScheduleTypeDef(_RequiredPrefetchScheduleTypeDef, _OptionalPrefetchScheduleTypeDef):
+    pass
+
+
 PutChannelPolicyRequestRequestTypeDef = TypedDict(
     "PutChannelPolicyRequestRequestTypeDef",
     {
